# colab_everything
> Python library to run streamlit, flask, fastapi, etc on google colab.


## Install

`pip install colab_everything`

## How to use

**Note:** Make sure you have `Streamlit` installed before running the below code.

You can use `pip` to install `Streamlit`

```
pip install streamlit
```

```python
from colab_everything import ColabStreamlit
ColabStreamlit('hello') # streamlit app path
```

    Streamlit app can be accessed on: https://27b3dd7d3f04.ngrok.io

